@@ -1,6 +1,6 @@
     /*
 
-    $Id: kedit.cpp,v 1.44.2.2 1999/02/11 11:59:59 porten Exp $
+    $Id: kedit.cpp,v 1.44.2.3 1999/07/02 17:19:05 porten Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -1451,7 +1451,7 @@ void TopLevel::saveNetFile( const char *_url )
 	return;
     }
 
-    tmpFile.sprintf( "file:/tmp/kedit%i", time( 0L ) );
+    tmpFile.sprintf( "file:/tmp/kedit%li", time( 0L ) );
 
     eframe->toggleModified( TRUE );
     eframe->doSave( tmpFile.data() + 5 );
@@ -1547,7 +1547,7 @@ void TopLevel::openNetFile( const char *_url, int _mode )
     }
 
     setGeneralStatusField(i18n("Starting Job"));
-    tmpFile.sprintf( "file:/tmp/kedit%i", time( 0L ) );
+    tmpFile.sprintf( "file:/tmp/kedit%li", time( 0L ) );
     connect( kfm, SIGNAL( finished() ), this, SLOT( slotKFMFinished() ) );
     setGeneralStatusField(i18n("Connected"));
     kfm->copy( netFile.data(), tmpFile.data() );
