@@ -1,7 +1,7 @@
 
 /*
 
-    $Id: floppy.cpp,v 1.7.2.1 1999/03/12 17:20:41 porten Exp $
+    $Id: floppy.cpp,v 1.7.2.3 1999/07/05 00:42:44 porten Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
@@ -220,12 +220,12 @@ bool FloppyData::findDevice()
 
   if((QString) deviceComboBox->currentText() == (QString) FLOPPYA3){
     if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
-      device = "/dev/fd0h1440";
+      device = "/dev/fd0H1440";
       blocks = 1440;
       tracks = 80;
       mdev = "/dev/fd0";
-      if( access(device.data(),W_OK) < 0){
-	device = "/dev/fd0H1440";
+      if(access(device.data(),W_OK) < 0){
+	device = "/dev/fd0u1440";
       }
     }
     else{
@@ -233,6 +233,9 @@ bool FloppyData::findDevice()
       blocks = 720;
       tracks = 80;
       mdev = "/dev/fd0";
+      if(access(device.data(),W_OK) < 0){
+	device = "/dev/fd0u720";
+      }
     }
   }
 
@@ -253,12 +256,12 @@ bool FloppyData::findDevice()
 
   if((QString) deviceComboBox->currentText() == (QString) FLOPPYB3){
     if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
-      device = "/dev/fd1h1440";
+      device = "/dev/fd1H1440";
       blocks = 1400;
       tracks = 80;
       mdev = "/dev/fd1";
-      if( access(device.data(),W_OK) < 0){
-	device = "/dev/fd1H1440";
+      if(access(device.data(),W_OK) < 0){
+	device = "/dev/fd1u1440";
       }
     }
     else{
@@ -266,6 +269,9 @@ bool FloppyData::findDevice()
       blocks = 720;
       tracks = 80;
       mdev = "/dev/fd1";
+      if(access(device.data(),W_OK) < 0){
+	device = "/dev/fd1u720";
+      }
     }
   }
 
